# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/24 20:45
@Description: Description
@File: jwt_authentication_request.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class JwtAuthenticationRequest(BaseDto):
    """
    The JwtAuthenticationRequest was generated by Generator from the JwtAuthenticationRequest.java file.
    """
    userName: str
    password: str
    mfaToken: str = None
