# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/26 19:01
@Description: Description
@File: sso_token_retrieve_dto.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class SsoTokenRetrieveDto(BaseDto):
    """
    The SsoTokenRetrieveDto was generated by Generator from the SsoTokenRetrieveDto.java file.
    """
    tokenId: str
    userName: str
