# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/24 20:45
@Description: Description
@File: subject_auth_api.py
"""
from api_requester.http.eclinical_requests import *


class AdminSubjectAuthApi:
    """
    The AdminSubjectAuthApi was generated by Generator from the SubjectAuthController.java file.
    """

    @post('/auth/subject/login')
    def auth_subject_login_api(self, *args, **kwargs): ...

    @get('/auth/subject/logout')
    def auth_subject_logout_api(self, *args, **kwargs): ...

    @get('/auth/subject/me')
    def auth_subject_me_api(self, *args, **kwargs): ...

    @get('/auth/subject/verify/organization-code')
    def verify_organization_code_api(self, *args, **kwargs): ...
