# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/09/06 14:41
@Description: Description
@File: user_on_board_application_service.py
"""
from api_requester.core.admin.api.user_on_board_application_api import AdminUserOnBoardApplicationApi
from api_requester.core.admin.dto.cross_user_user_on_board_dto import CrossUserUserOnBoardDto
from api_requester.core.admin.dto.user_on_board_dto import UserOnBoardDto


class AdminUserOnBoardApplicationService(AdminUserOnBoardApplicationApi):
    """
    The AdminUserOnBoardApplicationService was generated by Generator from the UserOnBoardApplicationController.java file.
    """

    def __init__(self):
        AdminUserOnBoardApplicationApi.__init__(self)

    def get_company_list(self):
        return self.get_company_list_api()

    def get_user_onboard_application_list(self, company_id: int = None):
        return self.get_user_onboard_application_list_api(params=dict(companyId=company_id))

    def on_board(self, user_on_board_dto: UserOnBoardDto = None):
        return self.on_board_api(json=user_on_board_dto)

    def entry_portal(self):
        return self.entry_portal_api()

    def login_portal(self, cross_user_user_on_board_dto: CrossUserUserOnBoardDto = None):
        return self.login_portal_api(json=cross_user_user_on_board_dto)
