# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/24 20:45
@Description: Description
@File: reset_password_email_request_dto.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class ResetPasswordEmailRequestDto(BaseDto):
    """
    The ResetPasswordEmailRequestDto was generated by Generator from the ResetPasswordEmailRequestDto.java file.
    """
    userId: str = None
