# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2025/07/04 09:01
@Description: Description
@File: subject_jwt_authentication_request.py
"""
from dataclasses import dataclass

from api_requester.core.admin.dto.jwt_authentication_request import JwtAuthenticationRequest


@dataclass
class SubjectJwtAuthenticationRequest(JwtAuthenticationRequest):
    """
    The SubjectJwtAuthenticationRequest was generated by Generator from the SubjectJwtAuthenticationRequest.java file.
    """
    organizationCode: str = None
