# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/24 20:45
@Description: Description
@File: user_on_board_application_api.py
"""
from api_requester.http.eclinical_requests import *


class AdminUserOnBoardApplicationApi:
    """
    The AdminUserOnBoardApplicationApi was generated by Generator from the UserOnBoardApplicationController.java file.
    """
    
    @get('/user/onboard/company')
    def get_company_list_api(self, *args, **kwargs): ...
    
    @get('/user/onboard/applications')
    def get_user_onboard_application_list_api(self, *args, **kwargs): ...
    
    @post('/user/onboard')
    def on_board_api(self, *args, **kwargs): ...
    
    @get('/user/entry/portal')
    def entry_portal_api(self, *args, **kwargs): ...
    
    @post('/user/entry/portal')
    def login_portal_api(self, *args, **kwargs): ...
    