# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/01 17:01
@Description: Description
@File: subject_auth_api.py
"""
from api_requester.http.eclinical_requests import *


class CommonSubjectAuthApi:
    """
    The CommonSubjectAuthApi was generated by Generator from the SubjectAuthController.java file.
    """

    @post('/subject/auth/login')
    def subject_auth_login_api(self, *args, **kwargs): ...

    @get('/subject/refresh')
    def subject_refresh_api(self, *args, **kwargs): ...

    @get('/subject/auth/logout')
    def subject_auth_logout_api(self, *args, **kwargs): ...

    @get('/subject/me')
    def subject_me_api(self, *args, **kwargs): ...

    @get('/subject/name')
    def subject_api(self, *args, **kwargs): ...
