# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/08 14:20
@Description: Description
@File: ecoa_onboard_request_dto.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class EcoaOnboardRequestDto(BaseDto):
    """
    The EcoaOnboardRequestDto was generated by Generator from the EcoaOnboardRequestDto.java file.
    """
    sponsorId: int = None
    studyId: int = None
    envId: int = None
