# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/22 10:32
@Description: Description
@File: portal_login_t_ime.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class PortalLoginTIme(BaseDto):
    """
    The PortalLoginTIme was generated by Generator from the PortalLoginTIme.java file.
    """
    portalLoginTime: int = None
