# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/24 20:45
@Description: Description
@File: user_on_board_dto.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class UserOnBoardDto(BaseDto):
    """
    The UserOnBoardDto was generated by Generator from the UserOnBoardDto.java file.
    """
    applicationId: int
    sponsorId: int = None
    studyId: int = None
    envId: int = None
    workForCompanyId: int = None
    userId: int = None
    userType: str = None
    roleId: int = None
    token: str = None
    permissionId: int = None
    companyLevelLogin: bool = False
