# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/08 14:20
@Description: Description
@File: ecoa_auth_api.py
"""
from api_requester.http.eclinical_requests import *


class AdminEcoaAuthApi:
    """
    The AdminEcoaAuthApi was generated by Generator from the EcoaAuthController.java file.
    """

    @post('/auth/ecoa/login')
    def auth_ecoa_login_api(self, *args, **kwargs): ...

    @post('/auth/ecoa/login/sso')
    def create_authentication_token_from_sso_api(self, *args, **kwargs): ...

    @get('/auth/ecoa/logout')
    def auth_ecoa_logout_api(self, *args, **kwargs): ...

    @get('/auth/ecoa/me')
    def auth_ecoa_me_api(self, *args, **kwargs): ...

    @post('/auth/ecoa/reset_password')
    def reset_password_email_api(self, *args, **kwargs): ...

    @post('/auth/ecoa/study-list')
    def ecoa_study_list_api(self, *args, **kwargs): ...

    @post('/auth/ecoa/onboard')
    def onboard_api(self, *args, **kwargs): ...
