# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/01 17:01
@Description: Description
@File: subject_auth_service.py
"""
from api_requester.core.common.api.subject_auth_api import CommonSubjectAuthApi


class CommonSubjectAuthService(CommonSubjectAuthApi):
    """
    The CommonSubjectAuthService was generated by Generator from the SubjectAuthController.java file.
    """

    def __init__(self):
        CommonSubjectAuthApi.__init__(self)

    def subject_auth_login(self):
        return self.subject_auth_login_api()

    def subject_refresh(self):
        return self.subject_refresh_api()

    def subject_auth_logout(self):
        return self.subject_auth_logout_api()

    def subject_me(self):
        return self.subject_me_api()

    def subject(self):
        return self.subject_api()
