# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/11/22 10:32
@Description: Description
@File: ecoa_auth_api.py
"""
from api_requester.http.eclinical_requests import *


class CommonEcoaAuthApi:
    """
    The CommonEcoaAuthApi was generated by Generator from the EcoaAuthController.java file.
    """
    
    @post('/ecoa/auth/login')
    def create_authentication_token_api(self, *args, **kwargs): ...
    
    @get('/ecoa/refresh')
    def refresh_and_get_authentication_token_api(self, *args, **kwargs): ...
    
    @get('/ecoa/auth/logout')
    def logout_api(self, *args, **kwargs): ...
    
    @post('/ecoa/auth/all-study-logout')
    def all_study_logout_api(self, *args, **kwargs): ...
    
    @get('/ecoa/me')
    def me_api(self, *args, **kwargs): ...
    
    @get('/ecoa/name')
    def ecoa_account_api(self, *args, **kwargs): ...
    
    @post('/ecoa/change-password')
    def change_password_api(self, *args, **kwargs): ...
    
    @post('/ecoa/change-study-rel-language')
    def change_study_language_api(self, *args, **kwargs): ...
    